==> libdatetime-locale-perl_1.17.orig.tar.gz: DateTime-Locale-1.17/share/mg-MG.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "M",
    MEd => "E d/M",
    MMM => "MMM",
    MMMEd => "E d MMM",
    MMMMEd => "E d MMMM",
    "MMMMW-count-one" => "'week' W 'of' MMM",
    "MMMMW-count-other" => "'week' W 'of' MMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMd => "d/MM",
    MMdd => "dd/MM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMM => "MM/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'week' w 'of' Y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "mg-MG",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Alats",
    "Tal",
    "Alar",
    "Alak",
    "Zom",
    "Asab",
    "Alah",
  ],
  day_format_narrow => [
    "A",
    "T",
    "A",
    "A",
    "Z",
    "A",
    "A",
  ],
  day_format_wide => [
    "Alatsinainy",
    "Talata",
    "Alarobia",
    "Alakamisy",
    "Zoma",
    "Asabotsy",
    "Alahady",
  ],
  day_stand_alone_abbreviated => [
    "Alats",
    "Tal",
    "Alar",
    "Alak",
    "Zom",
    "Asab",
    "Alah",
  ],
  day_stand_alone_narrow => [
    "A",
    "T",
    "A",
    "A",
    "Z",
    "A",
    "A",
  ],
  day_stand_alone_wide => [
    "Alatsinainy",
    "Talata",
    "Alarobia",
    "Alakamisy",
    "Zoma",
    "Asabotsy",
    "Alahady",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "BC",
    "AD",
  ],
  era_wide => [
    "Alohan\N{U+2019}i JK",
    "Aorian\N{U+2019}i JK",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%d.%m.%Y",
  glibc_datetime_format => "%a %d %b %Y %T %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Malagasy",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Apr",
    "Mey",
    "Jon",
    "Jol",
    "Aog",
    "Sep",
    "Okt",
    "Nov",
    "Des",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Janoary",
    "Febroary",
    "Martsa",
    "Aprily",
    "Mey",
    "Jona",
    "Jolay",
    "Aogositra",
    "Septambra",
    "Oktobra",
    "Novambra",
    "Desambra",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Apr",
    "Mey",
    "Jon",
    "Jol",
    "Aog",
    "Sep",
    "Okt",
    "Nov",
    "Des",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Janoary",
    "Febroary",
    "Martsa",
    "Aprily",
    "Mey",
    "Jona",
    "Jolay",
    "Aogositra",
    "Septambra",
    "Oktobra",
    "Novambra",
    "Desambra",
  ],
  name => "Malagasy Madagascar",
  native_language => "Malagasy",
  native_name => "Malagasy Madagasikara",
  native_script => undef,
  native_territory => "Madagasikara",
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Telovolana voalohany",
    "Telovolana faharoa",
    "Telovolana fahatelo",
    "Telovolana fahefatra",
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Telovolana voalohany",
    "Telovolana faharoa",
    "Telovolana fahatelo",
    "Telovolana fahefatra",
  ],
  script => undef,
  territory => "Madagascar",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 32,
}

==> libdatetime-locale-perl_1.24.orig.tar.gz: DateTime-Locale-1.24/share/mg-MG.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "M",
    MEd => "E d/M",
    MMM => "MMM",
    MMMEd => "E d MMM",
    MMMMEd => "E d MMMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMd => "d/MM",
    MMdd => "dd/MM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMM => "MM/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "mg-MG",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Alats",
    "Tal",
    "Alar",
    "Alak",
    "Zom",
    "Asab",
    "Alah",
  ],
  day_format_narrow => [
    "A",
    "T",
    "A",
    "A",
    "Z",
    "A",
    "A",
  ],
  day_format_wide => [
    "Alatsinainy",
    "Talata",
    "Alarobia",
    "Alakamisy",
    "Zoma",
    "Asabotsy",
    "Alahady",
  ],
  day_stand_alone_abbreviated => [
    "Alats",
    "Tal",
    "Alar",
    "Alak",
    "Zom",
    "Asab",
    "Alah",
  ],
  day_stand_alone_narrow => [
    "A",
    "T",
    "A",
    "A",
    "Z",
    "A",
    "A",
  ],
  day_stand_alone_wide => [
    "Alatsinainy",
    "Talata",
    "Alarobia",
    "Alakamisy",
    "Zoma",
    "Asabotsy",
    "Alahady",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "BC",
    "AD",
  ],
  era_wide => [
    "Alohan\N{U+2019}i JK",
    "Aorian\N{U+2019}i JK",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%d.%m.%Y",
  glibc_datetime_format => "%a %d %b %Y %T %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Malagasy",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Apr",
    "Mey",
    "Jon",
    "Jol",
    "Aog",
    "Sep",
    "Okt",
    "Nov",
    "Des",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Janoary",
    "Febroary",
    "Martsa",
    "Aprily",
    "Mey",
    "Jona",
    "Jolay",
    "Aogositra",
    "Septambra",
    "Oktobra",
    "Novambra",
    "Desambra",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Apr",
    "Mey",
    "Jon",
    "Jol",
    "Aog",
    "Sep",
    "Okt",
    "Nov",
    "Des",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Janoary",
    "Febroary",
    "Martsa",
    "Aprily",
    "Mey",
    "Jona",
    "Jolay",
    "Aogositra",
    "Septambra",
    "Oktobra",
    "Novambra",
    "Desambra",
  ],
  name => "Malagasy Madagascar",
  native_language => "Malagasy",
  native_name => "Malagasy Madagasikara",
  native_script => undef,
  native_territory => "Madagasikara",
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Telovolana voalohany",
    "Telovolana faharoa",
    "Telovolana fahatelo",
    "Telovolana fahefatra",
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Telovolana voalohany",
    "Telovolana faharoa",
    "Telovolana fahatelo",
    "Telovolana fahefatra",
  ],
  script => undef,
  territory => "Madagascar",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 35,
}
